@@ -39,6 +39,11 @@ class QLDBDriver:
 
 
     def add_attribute(self, table_name, identifier, attribute_name, value = None):
+        tables = self.list_tables()
+
+        if not table_name in tables:
+            raise Exception("Table not found!")
+
         if isinstance(value, str):
             default_value = f"'{value}'"
         elif isinstance(value, numbers.Number):
@@ -60,14 +65,22 @@ class QLDBDriver:
 
 
     def remove_attribute(self, table_name, identifier, attribute_name):
+        tables = self.list_tables()
+
+        if not table_name in tables:
+            raise Exception("Table not found!")
+
         statement = f"SELECT {identifier} FROM {table_name}"
         
         ids = self.query(statement)
 
         for id in ids:
             statement = f"FROM {table_name} WHERE {identifier} = {id[identifier]} REMOVE {attribute_name}"
-
-            self.qldb_driver.execute_lambda(lambda x: self.execute(x, statement))
+            
+            try:
+                self.qldb_driver.execute_lambda(lambda x: self.execute(x, statement))
+            except:
+                pass
 
 
     def list_tables(self):
